@@ -2,7 +2,7 @@
 import argparse
 import logging
 
-from gstomd.corpus import GsuiteToMd
+from gstomd.convert import GsuiteToMd
 
 
 def main():
@@ -24,7 +24,7 @@ def main():
         "--config",
         action="store",
         type=str,
-        help="Configuration file for PyDrive2",
+        help="Configuration file for PyDrive",
         default="",
     )
     my_parser.add_argument(
@@ -34,13 +34,7 @@ def main():
         required=True,
         help="Id of the folder to be converted",
     )
-    my_parser.add_argument(
-        "--folder_name",
-        action="store",
-        type=str,
-        help="Name of the folder to be create created.",
-        default="",
-    )
+
     my_parser.add_argument(
         "--dest",
         action="store",
@@ -51,7 +45,6 @@ def main():
 
     dest_folder_name = args.dest
     folder_id = args.folder_id
-    folder_name = args.folder_name
     args = my_parser.parse_args()
     if args.verbose:
         logging.basicConfig(level=logging.INFO)
@@ -64,7 +57,7 @@ def main():
     logger.debug("gsuiteTomd  Created")
 
     gstomd.Folder(
-        folder_id=folder_id, root_folder_name=folder_name,
+        folder_id=folder_id,
     )
 
 
